@@ -24,11 +24,11 @@ SOFTWARE.
 
 from asyncio import AbstractEventLoop, get_event_loop
 from inspect import iscoroutinefunction
-from typing import Callable, List, Union, Tuple
+from typing import Callable, List, Tuple, Union
 
 from .http import HTTPClient
-from .ws import GatewayClient
 from .objects import Intents
+from .ws import GatewayClient
 
 
 class CordedClient:
@@ -77,7 +77,7 @@ class CordedClient:
         for event in events:
             self.gateway.listeners[event].append(callback)
 
-    def on(self, *events: List[str]) -> Callable:
+    def on(self, *events: str) -> Callable:
         def wrapper(func):
             self.add_listener(events, func)
             return func
