@@ -5,11 +5,11 @@ class CordedError(Exception):
     pass
 
 
-## HTTP Errors
+# HTTP Errors
 
 
 class HTTPError(CordedError):
-    def __init__(self, response: ClientResponse):
+    def __init__(self, response: ClientResponse) -> None:
         self.response = response
 
 
