@@ -1,7 +1,9 @@
 from .client import HTTPClient
+from .file import File
 from .route import Route
 
 __all__ = (
+    File,
     HTTPClient,
     Route,
 )
