@@ -22,7 +22,6 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-from time import time
 from asyncio import AbstractEventLoop, Semaphore
 
 
@@ -38,9 +37,6 @@ class Ratelimiter:
         self.per = per
         self.loop = loop
 
-        self.current = 0
-        self.current_t = time()
-
         self.lock = Semaphore(rate)
 
     async def wait(self) -> None:
