@@ -22,18 +22,21 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-from aiohttp import WSMessage, WSMsgType
-from asyncio import AbstractEventLoop, sleep, Task
+from asyncio import AbstractEventLoop, Task, sleep
 from sys import platform
 from time import time
 
-from .ratelimiter import Ratelimiter
+from aiohttp import WSMessage, WSMsgType
 
-from corded.objects.constants import GatewayOps, GatewayCloseCodes as CloseCodes
+import corded
+from corded.objects.constants import GatewayCloseCodes as CloseCodes
+from corded.objects.constants import GatewayOps
+
+from .ratelimiter import Ratelimiter
 
 
 class Shard:
-    def __init__(self, id: int, parent, loop: AbstractEventLoop) -> None:
+    def __init__(self, id: int, parent: "corded.ws.GatewayClient", loop: AbstractEventLoop) -> None:
         """A shard to connect to the Discord gateway to receive and send events.
 
         Args:
@@ -56,7 +59,6 @@ class Shard:
         self.heartbeat_task = None
         self.last_heartbeat_send = None
         self.recieved_ack = True
-        self.failed_heartbeats = 0
         self.latency = None
 
         self.pacemaker: Task = None
@@ -77,12 +79,13 @@ class Shard:
         if not self.url:
             self.url = (await self.parent.http.get_gateway()).url
 
-        await self.spawn_ws()
+        while True:
+            await self.spawn_ws()
 
-        if self.session:
-            await self.resume()
+            if self.session:
+                await self.resume()
 
-        await self.start_reader()
+            await self.start_reader()
 
     async def close(self) -> None:
         """Gracefully close the connection."""
@@ -105,7 +108,10 @@ class Shard:
         await self.send_limiter.wait()
 
         self.loop.create_task(self.parent.dispatch_send(self, data))
-        await self.ws.send_json(data)
+        try:
+            await self.ws.send_json(data)
+        except ConnectionResetError:
+            exit(1)
 
     async def identify(self) -> None:
         """Sends an identfy payload to the gateway."""
@@ -221,11 +227,7 @@ class Shard:
 
         while True:
             if not self.recieved_ack:
-                self.failed_heartbeats += 1
-
-                await self.close()
-                await self.resume()
-                return
+                return await self.close()
 
             await self.heartbeat()
             self.recieved_ack = False
